@@ -1,8 +1,8 @@
 use crate::cli::Opt;
 use crate::theme::Theme;
 use clap::arg_enum;
-use libmacchina::traits::ReadoutError;
 use libmacchina::traits::ShellFormat;
+use libmacchina::traits::{ReadoutError, ShellKind};
 use libmacchina::{BatteryReadout, GeneralReadout, KernelReadout, MemoryReadout, PackageReadout};
 use serde::{Deserialize, Serialize};
 use std::borrow::Cow;
@@ -27,7 +27,7 @@ arg_enum! {
         Terminal,
         Uptime,
         Processor,
-        ProcessorUsage,
+        ProcessorLoad,
         Memory,
         Battery,
         LocalIP,
@@ -120,6 +120,11 @@ pub fn get_all_readouts<'a>(
     let mut readout_values = Vec::with_capacity(ReadoutKey::variants().len());
     let general_readout = GeneralReadout::new();
 
+    let mut tts = false;
+    if cfg!(feature = "tts") {
+        tts = true;
+    }
+
     if should_display.contains(&ReadoutKey::Host) {
         match (general_readout.username(), general_readout.hostname()) {
             (Ok(u), Ok(h)) => {
@@ -230,16 +235,15 @@ pub fn get_all_readouts<'a>(
     }
 
     if should_display.contains(&ReadoutKey::Shell) {
-        match opt.short_shell {
-            true => match general_readout.shell(ShellFormat::Relative) {
-                Ok(s) => readout_values.push(Readout::new(ReadoutKey::Shell, s)),
-                Err(e) => readout_values.push(Readout::new_err(ReadoutKey::Shell, e)),
-            },
-            false => match general_readout.shell(ShellFormat::Absolute) {
-                Ok(s) => readout_values.push(Readout::new(ReadoutKey::Shell, s)),
-                Err(e) => readout_values.push(Readout::new_err(ReadoutKey::Shell, e)),
-            },
-        }
+        let (ls, cs) = (
+            if opt.long_shell { ShellFormat::Absolute } else { ShellFormat::Relative },
+            if opt.current_shell { ShellKind::Current } else { ShellKind::Default },
+        );
+
+        match general_readout.shell(ls, cs) {
+            Ok(s) => readout_values.push(Readout::new(ReadoutKey::Shell, s)),
+            Err(e) => readout_values.push(Readout::new_err(ReadoutKey::Shell, e)),
+        };
     }
 
     if should_display.contains(&ReadoutKey::Uptime) {
@@ -267,25 +271,24 @@ pub fn get_all_readouts<'a>(
         }
     }
 
-    if should_display.contains(&ReadoutKey::ProcessorUsage) {
-        match (general_readout.cpu_usage(), opt.bar) {
-            (Ok(u), true) => {
+    if should_display.contains(&ReadoutKey::ProcessorLoad) {
+        match (general_readout.cpu_usage(), opt.bar, tts) {
+            (Ok(u), true, false) => {
                 if u > 100 {
                     readout_values.push(Readout::new(
-                        ReadoutKey::ProcessorUsage,
+                        ReadoutKey::ProcessorLoad,
                         create_bar(theme, crate::bars::num_to_blocks(100_u8)),
                     ))
                 }
                 readout_values.push(Readout::new(
-                    ReadoutKey::ProcessorUsage,
+                    ReadoutKey::ProcessorLoad,
                     create_bar(theme, crate::bars::num_to_blocks(u as u8)),
                 ))
             }
-            (Ok(u), false) => readout_values.push(Readout::new(
-                ReadoutKey::ProcessorUsage,
-                format_cpu_usage(u),
-            )),
-            (Err(e), _) => readout_values.push(Readout::new_err(ReadoutKey::ProcessorUsage, e)),
+            (Ok(u), _, _) => {
+                readout_values.push(Readout::new(ReadoutKey::ProcessorLoad, format_cpu_usage(u)))
+            }
+            (Err(e), _, _) => readout_values.push(Readout::new_err(ReadoutKey::ProcessorLoad, e)),
         }
     }
 
@@ -297,15 +300,16 @@ pub fn get_all_readouts<'a>(
         let total = memory_readout.total();
         let used = memory_readout.used();
 
-        match (total, used, opt.bar) {
-            (Ok(total), Ok(used), true) => {
-                let bar = create_bar(theme, crate::bars::memory(used, total));
-                readout_values.push(Readout::new(ReadoutKey::Memory, bar))
+        match (total, used) {
+            (Ok(total), Ok(used)) => {
+                if opt.bar && !tts {
+                    let bar = create_bar(theme, crate::bars::memory(used, total));
+                    readout_values.push(Readout::new(ReadoutKey::Memory, bar))
+                } else {
+                    readout_values.push(Readout::new(ReadoutKey::Memory, format_mem(total, used)))
+                }
             }
-            (Ok(total), Ok(used), false) => {
-                readout_values.push(Readout::new(ReadoutKey::Memory, format_mem(total, used)))
-            }
-            (Err(e), _, _) | (_, Err(e), _) => {
+            (Err(e), _) | (_, Err(e)) => {
                 readout_values.push(Readout::new_err(ReadoutKey::Memory, e))
             }
         }
@@ -323,7 +327,7 @@ pub fn get_all_readouts<'a>(
 
         match (percentage, state) {
             (Ok(p), Ok(s)) => {
-                if opt.bar {
+                if opt.bar && !tts {
                     let bar = create_bar(theme, crate::bars::num_to_blocks(p));
                     readout_values.push(Readout::new(key, bar));
                 } else {
